import os
import unittest

from aoch import read_file


class TestHelpers(unittest.TestCase):
    def test_read_file(self):
        expected_data = '-1\n-19\n-7'
        file_path = os.path.join(os.path.dirname(__file__), 'resources/input.txt')
        data = read_file(file_path)
        self.assertEqual(expected_data, data, 'Data should match expected data.')



import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="advent-of-code-helpers",
    version="0.0.2",
    author="Example Author",
    author_email="author@example.com",
    license="MIT",
    description="Advent of Code helper functions",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    url="https://github.com/pypa/sampleproject",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries"
    ],
    install_requires=["nose2"]
)
